package framework;

import java.io.IOException;
import java.util.Vector;
import javax.microedition.lcdui.Graphics;
import javax.microedition.lcdui.Image;
import no.tellu.cdlc.gui.*;
import no.tellu.cdlc.util.CanvasUtil;

/**
 * CheckBoxelement.java
 * <p/>
 * Draws (a) check box(es).
 * <p/>
 * The check box alternatives are set in the choices vector by
 * calling setChoices(Vector choices).
 * <p/>
 * Pressing fire checks/unchecks the selected check box.
 */
public class CheckBoxElement extends GuiElement {

	private Vector choices = new Vector();
	
	private boolean chosen = false;

	private int checkX;
	
	private int checkboxSize = 12;
	
	private Image checkboxImageSelected = null;
	private Image checkboxImageNotSelected = null;
	
	/**
	 * Constructor CheckBoxElement
	 */	
	public CheckBoxElement(){
		super();
		init();
	}
	
	/**
	 * Initialises all necessary values and images.
	 *
	 */
	private void init(){
		setFrameSize(3);
        setInsets(-1,-1,4,2);
		setSelectable(true);
		checkboxSize = getFontHeight() / 2 + 4;		
		try{
			checkboxImageSelected = GuiDisplay.getImage("/checkboxselected.png");
			checkboxImageNotSelected = GuiDisplay.getImage("/checkboxnotselected.png");
			
			checkboxImageSelected = CanvasUtil.resize(checkboxImageSelected, checkboxSize, checkboxSize);
			checkboxImageNotSelected = CanvasUtil.resize(checkboxImageNotSelected, checkboxSize, checkboxSize);			
		} catch(IOException e){
            e.printStackTrace();
        }
	}
		
	/**
	 * Controls the height of the check box element.
	 */
	public void elementLayoutManager() {
		setHeight(getFontHeight());
    }
	
	/**
	 * Paints the check box, its text and a dotted rectangle around it if 
	 * it is selected.
	 */
	public void paint(Graphics g, boolean selected) {
		checkX = getX();
		
		int selectedWidth = 0;
		
		int f = g.getColor();
		
		if(choices.size() > 1){ 
			//TODO draw checkboxes, remember that several can be chosen
		} else {
			//Draws one checkbox, text on the right side
			if(checkboxImageNotSelected == null || checkboxImageSelected == null){
				//TODO draw checkbox
			
			} else{
				if(chosen) g.drawImage(checkboxImageSelected, checkX + 3 , getY() + 3, Graphics.TOP | Graphics.LEFT);
				else g.drawImage(checkboxImageNotSelected, checkX + 3, getY() + 3, Graphics.TOP | Graphics.LEFT);
				
				g.setColor(GuiWindow.textFieldTextColour);
				getFont().drawString(g, (String)choices.elementAt(0), checkX + 20, getY() + 1, Graphics.TOP | Graphics.LEFT);
				
				if(selected){
					//Draws a dotted rectangle around the checkbox
					g.setColor(GuiWindow.textColour);
					int stringLength = getFont().getWidthOfString((String)choices.elementAt(0));
					selectedWidth = 20 + stringLength + 2;
					int strokeStyle = g.getStrokeStyle();
					g.setStrokeStyle(Graphics.DOTTED);
					g.drawRect(checkX, getY(), selectedWidth, getHeight());
					g.setStrokeStyle(strokeStyle);
				}
			}
		}
		g.setColor(f);
	}

	/**
	 * Sets the check box alternative(s).
	 * @param choices a vector containing string alternatives
	 */
	public void setChoices(Vector choices){
		this.choices = choices;
	}
	
	/**
	 * Sets the check box to be chosen if it is not already, and unchooses
	 * it if it is chosen.
	 */
	public boolean fire(int key) {
		chosen = !chosen;
		return true;	
	}

}
