package framework;

import no.tellu.cdlc.gui.*;

/**
 * MapLayout.java
 * <p/>
 * Handles the layout of a panel containing a map and POIs.
 */
public class MapLayout implements LayoutManager {

	/**
	 * Empty.
	 * MapLayout must implement the inherited abstract method
	 * LayoutManager.addLayoutComponent(GuiElement, int).
	 */
    public void addLayoutComponent(GuiElement comp, int constraint) {
    }

    /**
	 * Empty.
	 * MapLayout must implement the inherited abstract method
	 * LayoutManager.removeLayoutComponent(GuiElement).
	 */
    public void removeLayoutComponent(GuiElement comp) {
    }

    /**
     * Calculates the size dimensions for the specified
     * container, given the components it contains.
     *
     * @param parent the container to be laid out
     * @return the layout size to be paintend
     */
    public Dimension minimumLayoutSize(GuiPanel parent) {
        return new Dimension(10, 10);
    }

    /**
     * Calculates the preferred size dimensions for the specified
     * container, given the components it contains.
     *
     * @param parent the container to be laid out
     * @return the layout size to be paintend
     */
    public Dimension preferredLayoutSize(GuiPanel parent) {
        Dimension dim = new Dimension(10, 10);
        if (parent.getElementCount() > 0) {
            GuiElement m = parent.getElement(0);
            dim.width = m.getPreferredWidth() + parent.getInsetTop() + parent.getInsetBottom();
            dim.height = m.getPreferredHeight() + parent.getInsetLeft() + parent.getInsetRight();
        }
        return dim;
    }

    /**
     * Sets the x and y coordinates of the MapElement and POIElement.
     *
     * @param parent the specified component being laid out
     */
    public void layoutContainer(GuiPanel parent) {
        GuiElement m = parent.getElement(0);
        m.setX(parent.getInsetLeft());
        m.setY(parent.getInsetTop());

        if (parent.getElement(1) != null) {
            GuiElement poi = parent.getElement(1);
            poi.setX(parent.getInsetLeft());
            poi.setY(parent.getInsetTop());
        }
    }

    /**
	 * Empty.
	 * MapLayout must implement the inherited abstract method
	 * LayoutManager.setVerticalGap(int).
	 */
    public void setVerticalGap(int verticalSpacing) {
        throw new GuiRuntimeException("Method not implemented");
    }

    /**
     * Get vertical spacing between layed out elements.
     * 
     * @return 0
     */
    public int getVerticalGap() {
        return 0;
    }

    /**
	 * Empty.
	 * MapLayout must implement the inherited abstract method
	 * LayoutManager.setHorizontalGap(int).
	 */
    public void setHorizontalGap(int horizontalSpacing) {
        throw new GuiRuntimeException("Method not implemented");
    }

    /**
     * Get horizontal spacing between layed out elements.
     * 
     * @return 0
     */
    public int getHorizontalGap() {
        return 0;
    }

    /**
     * Get the constraint applied when the component was added.
     *
     * @param comp component
     * @return constraint return -1 if not available
     */
    public int getConstraint(GuiElement comp) {
        return -1;
    }


}
