package framework;

/**
 * POIInformation.java
 * <p/>
 * Contains a POI's key information that is not related to coordinates.
 * <p>
 * Use setExtraPopupInfo() to set any extra infomation to be drawn in
 * the popup of a POI in a map
 */
public class POIInformation {
	
	private String name;
	private String streetAddress;
	private String postCode;
	private String postAddress;
	
	private String extraPopupInfo = "";

	/**
	 * Constructor POIInformation
	 * @param name				Name of the POI
	 * @param streetAddress		The street address of the POI
	 * @param postCode			The POI's post-/zipcode
	 * @param postAddress		The POI's post address
	 */
	public POIInformation(String name, String streetAddress, String postCode, String postAddress) {
		this.name = name;
		this.streetAddress = streetAddress;
		this.postCode = postCode;
		this.postAddress = postAddress;
	}

	/**
	 * 
	 * @return name of the POI
	 */
	public String getName() {
		return name;
	}

	/**
	 * Sets the name of the POI.
	 * @param name name of the POI
	 */
	public void setName(String name) {
		this.name = name;
	}
	
	/**
	 * 
	 * @return the street address of the POI
	 */
	public String getStreetAddress() {
		return streetAddress;
	}

	/**
	 * Sets the street address of the POI.
	 * @param streetAddress the street address of the POI
	 */
	public void setStreetAddress(String streetAddress) {
		this.streetAddress = streetAddress;
	}

	/**
	 * 
	 * @return the post address of the POI
	 */
	public String getPostAddress() {
		return postAddress;
	}

	/**
	 * Sets the post address of the POI.
	 * @param postAddress the post address of the POI
	 */
	public void setPostAddress(String postAddress) {
		this.postAddress = postAddress;
	}

	/**
	 * 
	 * @return the postcode of the POI
	 */
	public String getPostCode() {
		return postCode;
	}

	/**
	 * Sets the post code of the POI.
	 * @param postCode the post code of the POI
	 */
	public void setPostCode(String postCode) {
		this.postCode = postCode;
	}
	
	/**
	 * Gets extra info about the POI, to be drawn in a popup.
	 * @return the string with extra info about the POI
	 */
	public String getExtraPopupInfo(){
		return extraPopupInfo;
	}
	
	/**
	 * Sets the extra POI info to be drawn in a popup.
	 * @param extraPopupInfo the extra info about the POI
	 */
	public void setExtraPopupInfo(String extraPopupInfo){
		this.extraPopupInfo = extraPopupInfo;
	}	

}
