package framework;

import no.tellu.commonplatform.serviceframe.common.map.MapBoundingBox;

/**
 * POIObject.java
 * <p/>
 * Contains all POI information.
 * <p/>
 * A POI is selectable by default. Use setNotSelectable() if the POI is not
 * supposed to be selectable.
 * <p/>
 * This is originally POIObject.java in 
 * no.tellu.commonplatform.serviceframe.common.map, Methods for finding
 * x and y coordinates to a POI in a map, variables 'id', 'selected', 
 * 'info', and 'selectable' have been added and the variables 'longitude' and
 * 'latitude' have been changed to 'easting' and 'northing'. Redundant code from 
 * no.tellu.commonplatform.serviceframe.common.map.POIObject has been
 * removed from this file.
 */
public class POIObject {
    private String easting;
    private String northing;
    private String id;
    private boolean selected = false;
    private POIInformation info = null;
    private boolean selectable = true;

    private String poiImage = null;

    /**
     * Constructor POIObject
     * @param easting			The easting coordinate
     * @param northing			The northing coordinate
     * @param id				ID of the POI
     * @param info				A POIInformation object containing general location information not related to coordinates
     */
    public POIObject(String easting, String northing, String id, POIInformation info) {
        this.easting = easting;
        this.northing = northing;
        this.id = id;
        this.info = info;
    }

    /**
     * 
     * @return the easting coordinate of the POI
     */
    public String getEasting() {
        return easting;
    }

    /**
     * Sets the easting coordinate of the POI.
     * @param easting the easting coordinate of the POI
     */
    public void setEasting(String easting) {
        this.easting = easting;
    }
    
    /**
     * 
     * @return the northing coordinate of the POI
     */
    public String getNorthing() {
        return northing;
    }

    /**
     * Sets the northing coordinate of the POI.
     * @param northing the northing coordinate of the POI
     */
    public void setNorthing(String northing) {
        this.northing = northing;
    }

    /**
     * Gets the POI information not coordinate related.
     * @return information about the POI not coordinate related
     */
    public POIInformation getInfo() {
		return info;
	}

    /**
     * Sets the POI information not coordinate related.
     * @param info the object with POI information
     */
	public void setInfo(POIInformation info) {
		this.info = info;
	}

	/**
	 * 
	 * @return the POI icon
	 */
    public String getPoiImage() {
        return poiImage;
    }

    /**
     * Sets the POI icon.
     * @param poiImage the icon ofthe POI
     */
    public void setPoiImage(String poiImage) {
        this.poiImage = poiImage;
    }
    
    /**
     * Sets the POI to be selected or unselects it.
     * @param selected true if the POI shoud be selected, false if not
     */
    public void setSelected(boolean selected){
    	this.selected = selected;
    }
 
    /**
     * 
     * @return true if the POI is selected, false if not
     */
    public boolean isSelected(){
    	return selected;
    }
    
    /**
     * Sets the POI to not be possible to select.
     *
     */
    public void setNotSelectable(){
    	selectable = false;
    }
 
    /**
     * 
     * @return true if the POI is selectable, false if not
     */
    public boolean isSelectable(){
    	return selectable;
    }
    
    /**
     * Finds the x coordinate of a POI within a given area
     * @param startX	The area's leftmost x coordinate
     * @param width		The width of the area
     * @param mbb		The area's coordinates
     * @return	The x coordinate
     */
    public int getXCoordinate(int startX, int width, MapBoundingBox mbb){
    	int lon = (Integer.valueOf(easting)).intValue();
    	double endX = startX + width;
    	double pix_per_lon = endX/(mbb.getMaxX() - mbb.getMinX());
    	double xValue = pix_per_lon * (lon - mbb.getMinX());
    	
        String s = ""+xValue;       
        int endIndex = s.indexOf(".");
        String newS = s.substring(0, endIndex);
        int x = (Integer.valueOf(newS)).intValue();
        
        return x;
    }
    
    /**
     * Finds the y coordinate of a POI within a given area
     * @param startY	The area's upper coordinate
     * @param height	The area's height
     * @param mbb		The area's coordinates
     * @return	The y coordinate
     */
    public int getYCoordinate(int startY, int height, MapBoundingBox mbb){
    	int lat = (Integer.valueOf(northing)).intValue();
    	double endY = startY + height;	
    	double pix_per_lat = endY/(mbb.getMaxY() - mbb.getMinY());
    	double yValue = pix_per_lat * (mbb.getMaxY() - lat);

        String s = ""+yValue;       
        int endIndex = s.indexOf(".");
        String newS = s.substring(0, endIndex);
        int y = (Integer.valueOf(newS)).intValue();
        return y;
    	
    }

    /**
     * 
     * @return the ID of the POI
     */
	public String getId() {
		return id;
	}

	/**
	 * Sets the ID of the POI.
	 * @param id the ID of the POI
	 */
	public void setId(String id) {
		this.id = id;
	}
	
}
