package framework;

import no.tellu.cdlc.gui.GuiDisplay;
import no.tellu.cdlc.gui.GuiElement;
import no.tellu.cdlc.gui.GuiWindow;
import no.tellu.cdlc.gui.ElementSkin;

import javax.microedition.lcdui.Graphics;
import javax.microedition.lcdui.Image;
import java.io.IOException;
import java.util.Vector;

/**
 * RadioButtonelement.java
 * <p/>
 * Draws  radio buttons
 * <p/>
 * The radio button alternatives are set in the choices vector by
 * calling setChoices(Vector choices).
 * <p/>
 * Pressing fire activates the radio button element. Selecting a different
 * button is then done by pressing right/left.
 */
public class RadioButtonElement extends GuiElement {

	private Vector choices = new Vector();
	private int selectedIndex = 0;
	private int columnWidth = 30;
	
	private int radioX = 0;
	
	private int buttonSize = 12;
	
	private Image buttonImageSelected = null;
	private Image buttonImageNotSelected = null;
	
	private boolean activated = false;
	
	/**
	 * Constructor RadioButtonElement
	 */
	public RadioButtonElement(){
		super();
		init();
	}
	
	/**
	 * Constructor RadioButtonElement
	 * @param elementId		The id of the object of this class
	 */
	public RadioButtonElement(String elementId){
		super(elementId);
		init();
	}
	
	/**
	 * Initialises all necessary values and images.
	 *
	 */
	private void init(){
		setFrameSize(3);
		setInsets(2,2,4,2);
		setSelectable(true);
		
		buttonSize = getFontHeight() / 2 + 2;
		
		try{
			buttonImageSelected = GuiDisplay.getImage("/radiobuttonselected.png");
			buttonImageNotSelected = GuiDisplay.getImage("/radiobuttonnotselected.png");	
		} catch(IOException e){
            e.printStackTrace();
        }
	}
	
	/**
     * Updates the width and the height of the RadioButtonElement
     */
	public void elementLayoutManager() {
		setWidth(radioX - getX());
		setHeight(getFontHeight());
    }
	
	/**
	 * Paints the radio buttons, their text and a dotted rectangle around
	 * the selected radio button.
	 */
	public void paint(Graphics g, boolean selected) {
		radioX = getX() + 2;
	
		int selectedWidth = 0;
		
		int f = g.getColor();
		for(int i = 0; i < choices.size(); i++){
			
			g.setColor(GuiWindow.textFieldTextColour);
			getFont().drawString(g, (String)choices.elementAt(i), radioX + 2, getY() + 1, Graphics.TOP | Graphics.LEFT);		
			
			int stringLength = getFont().getWidthOfString((String)choices.elementAt(i));
			columnWidth = stringLength + 15 + buttonSize;
			
			if(buttonImageNotSelected == null || buttonImageSelected == null){
				//Draws buttons if there are no images
				g.setColor(ElementSkin.WHITE);
				g.fillRoundRect(radioX + columnWidth - buttonSize - 8, getY() + buttonSize/2, buttonSize, buttonSize, 90, 90);
			
				g.setColor(GuiWindow.inputFieldTextColour);
				g.drawRoundRect(radioX + columnWidth - buttonSize - 8, getY() + buttonSize /2, buttonSize, buttonSize, 90, 90);
				
			
				if(selectedIndex == i){
					g.fillRoundRect(radioX + columnWidth - buttonSize - 6, getY() + buttonSize/2, buttonSize - 4, buttonSize - 4, 90, 90);
					selectedWidth = columnWidth - 5;
				}
			} else{
				//Draws images
				if(selectedIndex == i) {
					g.drawImage(buttonImageSelected, radioX + columnWidth - buttonSize - 8, getY() + 3, Graphics.TOP | Graphics.LEFT);
					selectedWidth = columnWidth - 5;
				}
				else g.drawImage(buttonImageNotSelected, radioX + columnWidth - buttonSize - 8, getY() + 3, Graphics.TOP | Graphics.LEFT);	
			}
			
			if(selectedIndex == i && activated && selected){
				g.setColor(GuiWindow.textColour);
				//Draws a dotted rectangle around the selected radio button
				int strokeStyle = g.getStrokeStyle();
				g.setStrokeStyle(Graphics.DOTTED);
				g.drawRect(radioX, getY(), selectedWidth, getHeight() - 1);
				g.setStrokeStyle(strokeStyle);
			}			
			radioX += columnWidth;		
		}
		g.setColor(f);
	}

	/**
	 * Sets the radio buttons' alternatives.
	 * @param choices a vector containing string alternatives
	 */
	public void setChoices(Vector choices){
		this.choices = choices;
	}

	/**
	 * 
	 * @return the alternative text of the selected radio button
	 */
	public String getStringValue(){
		return (String)choices.elementAt(selectedIndex);
	}
	
	/**
	 * 
	 * @return the index of the selected radio button
	 */
	public int getSelectedIndex(){
		return selectedIndex;
	}

	/**
	 * Handles the selection of radio buttons when the key for moving left
	 * is pressed.
	 */
	public boolean moveLeft(int x) {
		if(activated && selectedIndex > 0){
			selectedIndex--;
			return true;
		}
		return false;
	}

	/**
	 * Handles the selection of radio buttons when the key for moving right
	 * is pressed.
	 */
	public boolean moveRight(int x) {
		if(activated && selectedIndex < choices.size() - 1){
			selectedIndex++;
			return true;
		}
		return false;
	}

	/**
	 * Activates the radio buttons if they're not, deactivates them otherwise.
	 */
	public boolean fire(int key) {
		activated = !activated;
		return activated;
	}

}
