package kindergartenform;

import no.tellu.cdlc.gui.*;

import javax.microedition.lcdui.Graphics;

/**
 * ActivityElement.java
 * <p/>
 * Draws an activity element in a list of activities (ActivityPanelElement).
 * The element consists of a clock icon or time string, name of the activity 
 * and, if the activity has a description, an information icon.
 * <p/>
 * If the activity has extended information, pressing fire displays a 
 * description of the activity.
 */
public class ActivityElement extends GroupElement {

    TextElement extendedInfo;
    boolean extendedInfoSelected = false;
    int clockHeight = 0;
    ImageElement ie;
 
    /**
     * Constructor ActivityElement
     */
    public ActivityElement() { 
    	super();
    	setFrameSize(3);
    	setInsets(2, 2, 2, 2);
    	
//    	Creating the information icon	
		ie = new ImageElement("/info.png", 5);
		ie.setLabel("information");
		ie.setSelectable(false);
    }

    /**
     * Updates the layout of the extended information object
     */
    public void elementLayoutManager() {
    	    	
    	GuiElement element1 = (GuiElement) getGroup().elementAt(0);
    	clockHeight = element1.getHeight();
    	
    	if (extendedInfoSelected) {         
            if (extendedInfo == null) {
                extendedInfo = (TextElement) getGroupElelemnt("extendedInfo");
                if (extendedInfo != null)
                    extendedInfo.setWidth(getInnerWidth());
            }
        } 
    	super.elementLayoutManager();

    }

    /**
     * Paints the activity element
     */
    public void paint(Graphics g, boolean selected) {  	
    	drawBackground(g);
        g.translate(getX(), getY());
    	
        boolean infoImage = false;
        if(getGroupElelemnt("extendedInfo") != null) infoImage = true;
           	    	
        for (int i = 0; i < getGroup().size(); i++) {
            GuiElement element = (GuiElement) getGroup().elementAt(i);
            if (element != null && element.isVisible()) {          	
            	if(i == 0) {
            		element.paint(g, false, element.getX(), element.getY());
            	}	
            	if(i != 0) element.paint(g, selected, element.getX(), element.getY());
            }
        }
        if(infoImage && ie != null){
    		//Draws the info icon on the right side of the screen
    		ie.setX(getX() + getInnerWidth() - ie.getWidth() + getInsetRight() - 3);
    		ie.setY(6);
    		ie.paint(g, false);
        }
        
        infoImage = false;
        
        g.translate(-getX(), -getY());
        if (selected) drawBorder(g);
    }

    /**
     * Sets the extended information to be shown if it is not, hides it
     * if it is already shown.
     */
    public boolean fire(int key) {
    	extendedInfoSelected = !extendedInfoSelected;
      
        if(extendedInfo != null) extendedInfo.setHidden(!extendedInfoSelected);
        
        GuiElement ge = getGroupElelemnt("extendedInfo");
        if(ge != null) getGroupElelemnt("extendedInfo").setHidden(!extendedInfoSelected);
        return super.fire(key);
    }
    
    /**
     * Hides the extended information when the user leaves the activity element.
     *
     */
    private void leaveElement() {
        if (extendedInfo != null)
            extendedInfo.setHidden(true);
        extendedInfoSelected = false;
    }

    /**
     * Leaves the activity element and selects the element below.
     */
    public boolean moveDown(int x) {
        leaveElement();
        return super.moveDown(x);
    }

    /**
     * Leaves the activity element and selects the element above.
     */
    public boolean moveUp(int x) {
        leaveElement();
        return super.moveUp(x);
    }
}
