package kindergartenform;

import java.util.Vector;
import no.tellu.cdlc.gui.*;
import no.tellu.cdlc.serviceframe.messages.guicommands.GuiCmd;

/**
 * DailyRoutineWindow.java
 * <p/>
 * Contains the information shown in the daily routine window.
 */
public class DailyRoutineWindow extends GuiWindow {

	boolean showIcons;
	FormWindow fw;
	
	/**
	 * Constructor DailyRoutineWindow
	 * @param windowId				the ID of the window
	 * @param controllerApp			the controller application
	 * @param kindergartensInfo		the information about the kindergartens
	 * @param showIcons				whether or not to show the window with icons
	 * @param fw					the form's main window
	 */
	public DailyRoutineWindow(String windowId, GuiListener controllerApp, Vector kindergartensInfo, boolean showIcons, FormWindow fw) {
		super(windowId, controllerApp);
		this.showIcons = showIcons;
		this.fw = fw;
        this.getContentPane().setAllowScrollBars(false);
        this.getContentPane().setInsetRight(0);

        GuiHeading guiH = new GuiHeading("Sknad om barnehageplass", false);
		guiH.setFont(new GuiFont("MEDIUM_BOLD"));
		setHeading(guiH);	
		
		GuiPanel activityPanel = new GuiPanel("ape", new SimpleFlowLayout(SimpleFlowLayout.LEFT, 5, 1));
		activityPanel.setInsetTop(2);
		activityPanel.setInsetLeft(2);
		activityPanel.setInsetRight(0);	
		activityPanel.setAllowScrollBars(true);
		
        //The heading of the panel:
		TextElement te = new TextElement("Dagsrytme i Kanutten barnehage:");
		GuiFont headingFont = new GuiFont("SMALL_BOLD");
		GuiFont infoFont = new GuiFont("SMALL_PLAIN");
		te.setFont(headingFont);
		activityPanel.add(te);
		
		//Adding activities to an empty object of KindergartenPOI
		KindergartenPOIInfo infoKanutten = new KindergartenPOIInfo(null, null, null, null, null, null, null, null, null);
		infoKanutten.addActivity("07:30", "/clock7_30_2.png", "Kanutten pner, frokost", "Frilek for de som er ferdige med maten.");
		infoKanutten.addActivity("09:00", "/clock9_2.png", "Ulike bordaktiviteter", "Blant annet spill og forming.");
		infoKanutten.addActivity("10:00", "/clock10_2.PNG", "Fastlagte aktiviteter", "Pedagogiske aktiviteter relatert til dagens tema.");
		infoKanutten.addActivity("12:00", "/clock12_2.PNG", "Lunsj", "");
		infoKanutten.addActivity("12:30", "/clock12_30_2.png", "Fastlagte aktiviteter", "Pedagogiske aktiviteter utendrs, dersom vret tillater det.");
		infoKanutten.addActivity("14:00", "/clock14_2.png", "Fruktmltid", "");
		infoKanutten.addActivity("14:30", "/clock14_30_2.png", "Lek utendrs/innendrs", "Frilek, under oppsyn.");
		infoKanutten.addActivity("16:30", "/clock16_30_2.png", "Kanutten stenger", "");

		Vector activitesKanutten = infoKanutten.getActivities();

		ImageElement ie = null;
		TextElement te0 = null;

		//Puts the values of each activity into GUI elements and adds them to an
		//ActivityElement, which is added to the GuiPanel object:
		for(int j = 0; j < activitesKanutten.size(); j++){
			Activity temp = (Activity) activitesKanutten.elementAt(j);

			if(showIcons)ie = new ImageElement(temp.getTimeImage(), 5);
			else te0 = new TextElement(temp.getTimeString());

			TextElement te1 = new TextElement(temp.getActivity());

			TextElement te2 = new TextElement(temp.getExtendedInfo());
            te2.setElementId("extendedInfo");
            te2.setHidden(true);
				
			ActivityElement ae = new ActivityElement();
			
			if(showIcons)ae.addtoGroup(ie);
			else ae.addtoGroup(te0);
			
			ae.addtoGroup(te1);
			if(temp.getExtendedInfo().length() > 0) {
				ae.addtoGroup(te2);
			}
			activityPanel.add(ae);				
		}
		activityPanel.setCurrElementNo(1);
		
		addElement(activityPanel);

		GuiMenu guiMenu = new GuiMenu("Meny", this);
        guiMenu.addMenuElement(new GuiCmd("meny", "Tilbake"), null);
        setMenu(guiMenu);

        // Ready to display window
        GuiDisplay.setDisplay(this);
    }
	
	/**
	 * Shows the main window of the form when the 'Back' soft button is pressed.
	 */
	public void callbackAction(String elementId, int type, Object value) {
		if (elementId.equalsIgnoreCase("Meny")) {			
			GuiCmd cmd = (GuiCmd) ((MenuElement) value).getGuiCmd();
			if(cmd.getLabel().equals(fw.back.getLabel())){
				GuiDisplay.setDisplay(fw);
			}		
        }
        super.callbackAction(elementId, type, value);
    }

}
