package kindergartenform;

import framework.RadioButtonElement;
import no.tellu.cdlc.gui.GroupElement;
import no.tellu.cdlc.gui.GuiElement;
import no.tellu.cdlc.gui.TextElement;

import javax.microedition.lcdui.Graphics;

/**
 * FormGroupElement.java
 * <p/>
 * Created to support functionality that GroupElement doesn't. This 
 * functionality is moving left and right within a RadioButtonElement, 
 * drawing elements in a grid layout, and, if a GroupElement
 * has several selectable GUI elements, only marking one of them as
 * selected. 
 */
public class FormGroupElement extends GroupElement {

	int maxElementWidth = 0;
	
    /**
     * Constructor FormGroupElement
     */
	public FormGroupElement() {
    	super();
    }
    
	/**
	 * Constructor FormGroupElement
	 * @param elementId		the ID of the object of this class
	 */
    public FormGroupElement(String elementId) {
    	super(elementId);
    }

	/**
	 * Handles the layout of the FormGroupElement.
	 */
	public void elementLayoutManager() {
		//The FormGroupElement is divided into two columns
		//Finds the max. width of one column:
        setVerticalSpace(4);     
        setWidth(getPreferredWidth());      
		maxElementWidth = getInnerWidth() / 2 - getInsetLeft();
		
		for(int i = 0; i < getGroup().size(); i++){
			GuiElement guiElement = (GuiElement) getGroup().elementAt(i);
			if(guiElement instanceof RadioButtonElement){
				//Do not use the grid layout:
				for(int j = 0; j < getGroup().size(); j++){
					super.elementLayoutManager();
				}
				return;
			}
		}
		
		GuiElement guiElement;	
		for (int i = 0; i < getGroup().size(); i++) {
            guiElement = (GuiElement) getGroup().elementAt(i);
            
            if(i % 2 == 0) guiElement.setMaximumSize(maxElementWidth, guiElement.getPreferredHeight());
            else guiElement.setMaximumSize(getInnerWidth() - maxElementWidth, guiElement.getPreferredHeight());
            
            if (guiElement.isVisible())
                //Update each visible element's layout information
            	guiElement.elementLayoutManager();
        }
        
        int groupX = getInsetLeft();
        int groupY = getInsetTop();
        int groupYtext = groupY + 3;
        int lineHeight = 0;                                              
        boolean newLine = false;
        boolean moveTextDown = false;
        
        for (int i = 0; i < getGroup().size(); i++) {
        	guiElement = (GuiElement) getGroup().elementAt(i);     	
        	
        	if(i % 2 == 0){
        		GuiElement e2 = null;
        		if(i != (getGroup().size() - 1)) 
        			e2 = (GuiElement)(getGroup().elementAt(i + 1));
    		
        		//Checks if the text should be moved some pixels downwards
        		if(guiElement instanceof TextElement && e2 != null && !(e2 instanceof TextElement))
        			moveTextDown = true;
        	}
//        	The 2nd, 4th, etc GUI element is placed on the right side of the grid:        	
        	else groupX += maxElementWidth;

        	/* Position the guiElement */          
            if (guiElement != null && guiElement.isVisible()) {
                
            	//Place each 3rd, 5th, etc. element on a new line to create
            	//the grid layout
            	if(i > 1 && (i%2 == 0)) newLine = true;
            	
                if (!newLine || groupX == maxElementWidth) {
                	if(moveTextDown)guiElement.setElementPosition(groupX, groupYtext);
                	else guiElement.setElementPosition(groupX, groupY);
                } else {
                	// increment to next line
                	groupX = getInsetLeft();             	
                	groupY += lineHeight + getVerticalSpace();
                	groupYtext = groupY + 3;

                	if(moveTextDown)guiElement.setElementPosition(groupX, groupYtext);
                	else guiElement.setElementPosition(groupX, groupY);
                }

                /* Set width */
                if(i%2 == 0) {
                	guiElement.setWidth(maxElementWidth);      
                } else {
                    if(guiElement.getPreferredWidth() > getInnerWidth() - maxElementWidth)
                    	guiElement.setWidth(getInnerWidth() - maxElementWidth);
                    
                    else guiElement.setWidth(guiElement.getPreferredWidth());
                }
                
                newLine = false;
                moveTextDown = false;
                
                /* set line height */
                lineHeight = Math.max(lineHeight, guiElement.getHeight());
            }
            groupX = getInsetLeft();
        }
        
        if (isPreferredSizeSet()) {
            setHeight(getPreferredHeight());
        } else {
            setHeight(groupY + lineHeight + getInsetBottom());
        }
        setLayoutNeeded(false);            
	}

	/**
	 * Paints the group element.
	 */
	public void paint(Graphics g, boolean selected) {
        drawBackground(g);
        for (int i = 0; i < getGroup().size(); i++) {
            GuiElement element = (GuiElement) getGroup().elementAt(i);
            if (element != null && element.isVisible())
            	//Only mark one of the elements within a FormGroupElement as selected:
            	if(element == getCurrGuiElement())
                    element.paint(g, selected, getX() + element.getX(), getY() + element.getY());
                else
                    element.paint(g, false, getX() + element.getX(), getY() + element.getY());
        }
        if (selected)
            drawBorder(g);
    }
	   
    /**
     * Allows moving left within a FormGroupElement.
     */
    public boolean moveLeft(int x) {
		if(getCurrGuiElement() != null && getCurrGuiElement().isSelectable())
			return getCurrGuiElement().moveLeft(x);
		return false;
	}

    /**
     * Allows moving right within a FormGroupElement.
     */
	public boolean moveRight(int x) {
		if(getCurrGuiElement() != null && getCurrGuiElement().isSelectable())
			return getCurrGuiElement().moveRight(x);
		return false;
	}
	
}