package kindergartenform;

import framework.*;
import no.tellu.cdlc.gui.*;
import no.tellu.commonplatform.serviceframe.common.map.MapBoundingBox;

import javax.microedition.lcdui.Graphics;
import javax.microedition.lcdui.Image;
import java.util.Vector;

/**
 * FormPageTwoMap.java
 * <p/>
 * Contains the content of the second page of the form, presented in a map.
 */
public class FormPageTwoMap extends GuiPanel {

	private Vector pois;	
	POIElement poie;	
	FormWindow fw;	
	int i = -1;

	/**
	 * Constructor FormPageTwoMap
	 * initialises the content to be shown.
	 * @param elementId			the ID of the object of this class
	 * @param layoutMgr			the layout manager used in this form page
	 * @param kindergartens		the kindergartens of the form
	 */
	public FormPageTwoMap(String elementId, LayoutManager layoutMgr, Vector kindergartens,FormWindow fw) {
		super(elementId, layoutMgr);
		
		this.fw = fw;
		
		setInsetTop(3);
        setInsetLeft(3);

		GuiFont infoFont = new GuiFont("SMALL_PLAIN");
		
		//Creating a new panel for the map and POIs
		GuiPanel mapPane = new GuiPanel();
		
		mapPane.setBorderVisible(true);

		mapPane.setInsets(0, 0, 0, 0);
	    
	    //Adding a layout manager for the map
	    MapLayout ml = new MapLayout();
	    mapPane.setLayoutMgr(ml);	        
	    mapPane.setAutoLayout(true);
	    
	    //Creating the map image
	    Image image = null;
	    try{
			image = Image.createImage("/kart2.PNG");
		} catch (Exception e){}
		
		//Creating POIs
		POIObject poi1 = new POIObject("267869", "7039600", "1", (KindergartenPOIInfo)kindergartens.elementAt(0));		
		POIObject poi2 = new POIObject("268739", "7039640", "2", (KindergartenPOIInfo)kindergartens.elementAt(1));		
		POIObject poi3 = new POIObject("267405", "7038079", "3", (KindergartenPOIInfo)kindergartens.elementAt(2));
		POIObject poi4 = new POIObject("269037", "7038968", "4", (KindergartenPOIInfo)kindergartens.elementAt(3));
		POIObject poi5 = new POIObject("268688", "7037973", "5", (KindergartenPOIInfo)kindergartens.elementAt(4));
			
//		for non-commercial use unless permitted by the creator:
    	//http://www.iconarchive.com/category/buildings/the-village-icons-by-calle.html	    
		POIObject house = new POIObject("268018", "7038771", "Home", null);
		house.setPoiImage("/House-1-icon1.gif");
	    house.setNotSelectable();
	    
	    pois = new Vector();
	    pois.addElement(poi1);
		pois.addElement(poi2);
		pois.addElement(poi3);
		pois.addElement(poi4);
		pois.addElement(poi5);
		pois.addElement(house);
		
		//Creating the map area with coordinates
		MapBoundingBox mbb = new MapBoundingBox(267230,7037756,269470,7039819);
	    
		MapObject mapo = new MapObject(image, pois, mbb);
	    
	    MapElement me = new MapElement("1", 226, 190, mapo);
	    poie = new POIElement("2", me.getWidth(), me.getHeight(), mapo, 3);
	    
	    me.setLabel("MapElement");
	    poie.setLabel("POIElement");
    
	    mapPane.add(me);
	    mapPane.add(poie);
        mapPane.setHeight(me.getPreferredHeight());
        mapPane.setCurrGuiElement(poie);	    
	    add(mapPane);
	    
	    GroupElement ge2 = new GroupElement();
	    TextElement te = new TextElement("Sket ga 5 barnehager.",  25);
	    te.setFont(infoFont);
	    ge2.addtoGroup(te);
	    ge2.setBorderVisible(false);
	    ge2.setSelectable(false);
	    add(ge2);
	    
	    setCurrGuiElement(mapPane);
	}
	
	/**
	 * Handles the commands to be shown on the menu line.
	 */
	public void paint(Graphics g, boolean selected) {
		POIObject selPOI = poie.getSelectedPOI();

		if(selPOI != null){						
			int isSaved = poie.getPOIIndexInSavedVector(selPOI);
			
			//Check if the current selected has been saved
			if(isSaved != -1) {
				
				//Check if the choose command is on the menu line and remove it
				if(i != 1) {
					fw.guiMenu.removeMenuElement(fw.choose.getLabel());
				
					//Insert regret command
					fw.guiMenu.insertMenuElement(fw.regret, "root", 0);
					i = 1;
				}
			}
			else {
				//Check if the max. number to save is reached
				if(poie.getSavedPOIs().size() == poie.getMaxNumberOfPOIsToSave()){
					if(i == 0) fw.guiMenu.removeMenuElement(fw.choose.getLabel());
					else if(i == 1) fw.guiMenu.removeMenuElement(fw.regret.getLabel());
					i = 0;
					super.paint(g, selected);
					return;
				}

				//Check if the menu line has the regret command and remove it
				if(i != -1) fw.guiMenu.removeMenuElement(fw.regret.getLabel());
				
				//Check if the menu line already has the choose command
				if(i != 0){
					//Insert choose command
					fw.guiMenu.insertMenuElement(fw.choose, "root", 0);
					i = 0;
				}
			}
		}			
		super.paint(g, selected);
	}
	
	/**
	 * 
	 * @return the POIElement in the form page
	 */
	public POIElement getPOIElement(){
		return poie;
	}

	/**
	 * Removes the commands for choosing and regretting choice of kindergarten
	 * when the user leaves the form page.
	 */
	public void leavePanel() {
		fw.guiMenu.removeMenuElement(fw.regret.getLabel());
		fw.guiMenu.removeMenuElement(fw.choose.getLabel());
		i = -1;
	}
	
}