package kindergartenform;

import java.util.Vector;
import framework.POIInformation;

/**
 * KindergartenPOIInfo.java
 * <p/>
 * Contains kindergarten specificinformation. Activities have to be added by 
 * using addActivity(String timeString, String timeImage, String activity, 
 * String extendedInfo ).
 */
public class KindergartenPOIInfo extends POIInformation {

	private String district;
	private String owner;
	private String focusArea;
	private String openingHours;
	private Vector placeTypes;
	
	private Vector activities = new Vector();

	/**
	 * Constructor KindergartenPOIInfo
	 * @param name					name of the kindergarten
	 * @param streetAddress			street address of the kindergarten
	 * @param postCode				post code of the kindergarten
	 * @param postAddress			post address of the kindergarten
	 * @param district				the district the kindergarten is situated in
	 * @param owner					the owner of the kindergarten
	 * @param focusArea				the focus area of the kindergarten
	 * @param openingHours			the opening hours of the kindergarten
	 * @param placeTypes			the place types of the kindergarten
	 */
	public KindergartenPOIInfo(String name, String streetAddress,
			String postCode, String postAddress, String district, String owner,
			String focusArea, String openingHours, Vector placeTypes) {
		super(name, streetAddress, postCode, postAddress);
		
		this.district = district;
		this.owner = owner;
		this.focusArea = focusArea;
		this.openingHours = openingHours;
		this.placeTypes = placeTypes;		
		setExtraPopupInfo("");	
	}

	/**
	 * 
	 * @return the district of the kindergarten
	 */
	public String getDistrict() {
		return district;
	}

	/**
	 * Sets the district of the kindergarten.
	 * @param district the district of the kindergarten
	 */
	public void setDistrict(String district) {
		this.district = district;
	}

	/**
	 * 
	 * @return the focus area of the kindergarten
	 */
	public String getFocusArea() {
		return focusArea;
	}

	/**
	 * Sets the focus area of the kindergarten.
	 * @param focusArea the focus area of the kindergarten
	 */
	public void setFocusArea(String focusArea) {
		this.focusArea = focusArea;
	}

	/**
	 * 
	 * @return the opening hours of the kindergarten
	 */
	public String getOpeningHours() {
		return openingHours;
	}

	/**
	 * Sets the opening hours of the kindergarten.
	 * @param openingHours the opening hours of the kindergarten
	 */
	public void setOpeningHours(String openingHours) {
		this.openingHours = openingHours;
	}

	/**
	 * 
	 * @return the ownership of the kindergarten
	 */
	public String getOwner() {
		return owner;
	}

	/**
	 * Sets the ownership of the kindergarten.
	 * @param owner the ownership of the kindergarten
	 */
	public void setOwner(String owner) {
		this.owner = owner;
	}

	/**
	 * 
	 * @return the place types of the kindergarten
	 */
	public Vector getPlaceTypes() {
		return placeTypes;
	}

	/**
	 * Sets the place types of the kindergarten.
	 * @param placeTypes the place types of the kindergarten
	 */
	public void setPlaceTypes(Vector placeTypes) {
		this.placeTypes = placeTypes;
	}
	
	/**
	 * Adds an activitity to the kindergarten.
	 * @param timeString	the time represented by a string
	 * @param timeImage		the time represented by an icon
	 * @param activity		the name of the activity
	 * @param extendedInfo	the description of the activity
	 */
	public void addActivity(String timeString, String timeImage, String activity, String extendedInfo ){
		Activity act = new Activity(timeString, timeImage, activity, extendedInfo);
		activities.addElement(act);		
	}
	
	/**
	 * 
	 * @return the activities of the kindergarten
	 */
	public Vector getActivities(){
		return activities;
	}

}