package kindergartenform;

import no.tellu.cdlc.gui.GroupElement;
import no.tellu.cdlc.gui.GuiElement;
import no.tellu.cdlc.gui.ImageElement;
import no.tellu.cdlc.gui.TextElement;

import javax.microedition.lcdui.Graphics;
import java.util.Vector;

/**
 * SummaryElement.java
 * <p/>
 * Draws a summary element in a list of main topics.
 * The element consists of the name of the main topic and an 
 * information icon.
 * <p/>
 * Pressing fire displays the summarisation of the information given
 * in the main topic.
 */
public class SummaryElement extends GroupElement {

	Vector extendedInfo = new Vector();
	
	boolean extendedInfoSelected = false;
	
	ImageElement ie;

    /**
     * Constructor SummaryElement
     */
	public SummaryElement() { 
		ie = new ImageElement("/info.png", 5);
		ie.setLabel("information");
		ie.setSelectable(false);
    }

	/**
     * Updates the summary vector
     */
    public void elementLayoutManager() {
        if (extendedInfoSelected) {
            
            if (extendedInfo.size() == 0) {
                for(int i = 1; i < getGroup().size(); i++){
                	TextElement te = (TextElement)getGroup().elementAt(i);
                	te.setWidth(getInnerWidth());
                	extendedInfo.addElement(te);              	
                }
            }
        }      
        super.elementLayoutManager();
    }

    /**
     * Paints the summary element
     */
    public void paint(Graphics g, boolean selected) {  	
    	drawBackground(g);
        g.translate(getX(), getY());
    	   	    	
        for (int i = 0; i < getGroup().size(); i++) {
            GuiElement element = (GuiElement) getGroup().elementAt(i);
            if (element != null && element.isVisible()) {          	       	
            	
                element.paint(g, selected, element.getX(), element.getY());
            }
        }
        
//      Draws the info icon on the right side of the screen
		ie.setX(getX() + getInnerWidth() - ie.getWidth() + getInsetRight() - 3);
		ie.setY(6);
		ie.setSelectable(false);
		ie.paint(g, selected);
        
        g.translate(-getX(), -getY());
        if (selected)
            drawBorder(g);
    }

    /**
     * Sets the extended information to be shown if it is not, hidden otherwise.
     */
    public boolean fire(int key) {
    	extendedInfoSelected = !extendedInfoSelected;

        for(int i = 0; i < extendedInfo.size(); i++){
        	TextElement te = (TextElement)extendedInfo.elementAt(i);
        	te.setHidden(!extendedInfoSelected);
        	extendedInfo.insertElementAt(te, i);
        	extendedInfo.removeElementAt(i + 1);
        }
        
        for(int i = 1; i < getGroup().size(); i++){
            ((GuiElement)getGroup().elementAt(i)).setHidden(!extendedInfoSelected);
        }
        return super.fire(key);
    }
       
    /**
     * Sets the extended information to be hidden when the user leaves the
     * element.
     *
     */
    private void leaveElement() {
        if (extendedInfo != null){
        	for(int i = 0; i < extendedInfo.size(); i++){
            	TextElement te = (TextElement)extendedInfo.elementAt(i);
            	te.setHidden(true);
            	extendedInfo.insertElementAt(te, i);
            	extendedInfo.removeElementAt(i + 1);
            }       	
        }
    }

    /**
     * Leaves the summary element and selects the element below.
     */
    public boolean moveDown(int x) {
        leaveElement();
        return super.moveDown(x);
    }

    /**
     * Leaves the summary element and selects the element above.
     */
    public boolean moveUp(int x) {
        leaveElement();
        return super.moveUp(x);
    }
    
}